Learn R Programming

sdpt3r (version 0.1)

doptimal: D-Optimal Experimental Design

Description

doptimal creates input for sqlp to solve the D-Optimal Experimental Design problem - given an nxp matrix with p <= n, find the portion of points that maximizes det(A'A)

Usage

doptimal(V)

Arguments

V

a pxn matrix containing a set of n test vectors in dimension p (with p <= n)

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant C matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

Solves the D-optimal experimental design problem. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
data(DoptDesign)

out <- doptimal(DoptDesign)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b
OPTIONS <- out$OPTIONS

# }

Run the code above in your browser using DataLab