Learn R Programming

sdpt3r (version 0.1)

etp: Educational Testing Problem

Description

etp creates input for sqlp to solve the Educational Testing Problem - given a symmetric positive definite matrix S, how much can be subtracted from the diagonal elements of S such that the resulting matrix is positive semidefinite definite.

Usage

etp(B)

Arguments

B

A symmetric positive definite matrix

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant c matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

Solves the education testing problem. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
data(Betp)

out <- etp(Betp)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b

# }

Run the code above in your browser using DataLab