Learn R Programming

sdpt3r (version 0.1)

gpp: Graph Partitioning Problem

Description

gpp creates input for sqlp to solve the graph partitioning problem.

Usage

gpp(B, alpha)

Arguments

B

A weighted adjacency matrix

alpha

Any real value in (0,n^2)

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant c matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

Solves the graph partitioning problem. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
data(Bgpp)
alpha <- nrow(Bgpp)

out <- gpp(Bgpp, alpha)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b

# }

Run the code above in your browser using DataLab