Learn R Programming

sdpt3r (version 0.1)

lmi1: Linear Matrix Inequality 1

Description

lmi1 creates input for sqlp to solve a linear matrix inequality problem

Usage

lmi1(B)

Arguments

B

An mxn real valued matrix

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant c matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

Solves the type-1 linear matrix inequality problem. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
B <- matrix(c(-1,5,1,0,-2,1,0,0,-1), nrow=3)

out <- lmi1(B)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b

# }

Run the code above in your browser using DataLab