Learn R Programming

sdpt3r (version 0.1)

lmi2: Linear Matrix Inequality 2

Description

lmi2 creates input for sqlp to solve a linear matrix inequality problem

Usage

lmi2(A1, A2, B)

Arguments

A1

An nxm real valued matrix

A2

An nxm real valued matrix

B

An nxp real valued matrix

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant c matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

Solves the type-2 linear matrix inequality problem. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
A1 <- matrix(c(-1,0,1,0,-2,1,0,0,-1),3,3)
A2 <- A1 + 0.1*t(A1)
B  <- matrix(c(1,3,5,2,4,6),3,2)

out <- lmi2(A1,A2,B)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b

# }

Run the code above in your browser using DataLab