Learn R Programming

sdpt3r (version 0.1)

lmi3: Linear Matrix Inequality 3

Description

lmi3 creates input for sqlp to solve a linear matrix inequality problem

Usage

lmi3(A, B, G)

Arguments

A

An nxn real valued matrix

B

An mxn real valued matrix

G

An nxn real valued matrix

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant c matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

Solves the type-3 linear matrix inequality problem. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
A <- matrix(c(-1,0,1,0,-2,1,0,0,-1),3,3)
B <- matrix(c(1,2,3,4,5,6), 2, 3)
G <- matrix(1,3,3)

out <- lmi3(A,B,G)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b

# }

Run the code above in your browser using DataLab