Learn R Programming

sdpt3r (version 0.1)

lovasz: Lovasz Number of a Graph

Description

lovasz creates input for sqlp to find the Lovasz Number of a graph

Usage

lovasz(G)

Arguments

G

An adjacency matrix corresponding to a graph

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant c matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

Finds the maximum Shannon entropy of a graph, more commonly known as the Lovasz number. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
data(Glovasz)

out <- lovasz(Glovasz)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b

# }

Run the code above in your browser using DataLab