Learn R Programming

sdpt3r (version 0.1)

maxcut: Max-Cut Problem

Description

maxcut creates input for sqlp to solve the Max-Cut problem - given a graph B, find the maximum cut of the graph

Usage

maxcut(B)

Arguments

B

A (weighted) adjacency matrix corresponding to a graph

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant c matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

Determines the maximum cut for a graph B. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
data(Bmaxcut)

out <- maxcut(Bmaxcut)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b

# }

Run the code above in your browser using DataLab