Learn R Programming

sdpt3r (version 0.1)

maxkcut: Max-kCut Problem

Description

maxkcut creates input for sqlp to solve the Max-kCut Problem - given a graph object B, determine if a cut of at least size k exists.

Usage

maxkcut(B, K)

Arguments

B

A (weighted) adjacency matrix

K

An integer value, the minimum number of cuts in B

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant c matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

Determines if a cut of at least size k exists for a graph B. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
data(Bmaxkcut)

out <- maxkcut(Bmaxkcut,2)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b

# }

Run the code above in your browser using DataLab