Learn R Programming

sdpt3r (version 0.1)

minelips: The Minimum Ellipsoid Problem

Description

minelips creates input for sqlp to solve the minimum ellipsoid problem - given a set of n points, find the minimum volume ellipsoid that contains all the points

Usage

minelips(V)

Arguments

V

An nxp matrix consisting of the points to be contained in the ellipsoid

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant c matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

for a set of points (x1,...,xn) determines the ellipse of minimum volume that contains all points. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
data(Vminelips)

out <- minelips(Vminelips)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b
OPTIONS <- out$OPTIONS

# }

Run the code above in your browser using DataLab