Learn R Programming

sdpt3r (version 0.1)

nearcorr: Nearest Correlation Matrix Problem

Description

nearcorr creates input for sqlp to solve the nearest correlation matrix problem - given a approximate correlation matrix H, find the nearest correlation matrix X.

Usage

nearcorr(H)

Arguments

H

A symmetric matrix

Value

Returns an object of class sqlp_input, containing the following:

blk

A matrix object describing the block diagonal structure of the SQLP data

At

A matrix object containing constraint matrices for the primal-dual problem

C

A matrix object containing the constant c matrices in the primal objective function

b

A vector containing the right hand side of the equality constraints in the primal problem

OPTIONS

A list object specifying the value of parbarrier

Details

For a given approximate correlation matrix H, determines the nearest correlation matrix X. Mathematical and implementation details can be found in the vignette

Examples

Run this code
# NOT RUN {
data(Hnearcorr)

out <- nearcorr(Hnearcorr)
blk <- out$blk
At <- out$At
C <- out$C
b <- out$b

# }

Run the code above in your browser using DataLab