powered by
lmi1 creates input for sqlp to solve a linear matrix inequality problem
lmi1
lmi1(B)
An mxn real valued matrix
Returns an object of class sqlp_input, containing the following:
A matrix object describing the block diagonal structure of the SQLP data
A matrix object containing constraint matrices for the primal-dual problem
A matrix object containing the constant c matrices in the primal objective function
A vector containing the right hand side of the equality constraints in the primal problem
A list object specifying the value of parbarrier
Solves the type-1 linear matrix inequality problem. Mathematical and implementation details can be found in the vignette
# NOT RUN { B <- matrix(c(-1,5,1,0,-2,1,0,0,-1), nrow=3) out <- lmi1(B) blk <- out$blk At <- out$At C <- out$C b <- out$b # }
Run the code above in your browser using DataLab