powered by
lmi2 creates input for sqlp to solve a linear matrix inequality problem
lmi2
lmi2(A1, A2, B)
An nxm real valued matrix
An nxp real valued matrix
Returns an object of class sqlp_input, containing the following:
A matrix object describing the block diagonal structure of the SQLP data
A matrix object containing constraint matrices for the primal-dual problem
A matrix object containing the constant c matrices in the primal objective function
A vector containing the right hand side of the equality constraints in the primal problem
A list object specifying the value of parbarrier
Solves the type-2 linear matrix inequality problem. Mathematical and implementation details can be found in the vignette
# NOT RUN { A1 <- matrix(c(-1,0,1,0,-2,1,0,0,-1),3,3) A2 <- A1 + 0.1*t(A1) B <- matrix(c(1,3,5,2,4,6),3,2) out <- lmi2(A1,A2,B) blk <- out$blk At <- out$At C <- out$C b <- out$b # }
Run the code above in your browser using DataLab