powered by
lmi3 creates input for sqlp to solve a linear matrix inequality problem
lmi3
lmi3(A, B, G)
An nxn real valued matrix
An mxn real valued matrix
Returns an object of class sqlp_input, containing the following:
A matrix object describing the block diagonal structure of the SQLP data
A matrix object containing constraint matrices for the primal-dual problem
A matrix object containing the constant c matrices in the primal objective function
A vector containing the right hand side of the equality constraints in the primal problem
A list object specifying the value of parbarrier
Solves the type-3 linear matrix inequality problem. Mathematical and implementation details can be found in the vignette
# NOT RUN { A <- matrix(c(-1,0,1,0,-2,1,0,0,-1),3,3) B <- matrix(c(1,2,3,4,5,6), 2, 3) G <- matrix(1,3,3) out <- lmi3(A,B,G) blk <- out$blk At <- out$At C <- out$C b <- out$b # }
Run the code above in your browser using DataLab