Returns an object of class sqlp_input, containing the following:
blkA matrix object describing the block diagonal structure of the SQLP data
AtA matrix object containing constraint matrices for the primal-dual problem
CA matrix object containing the constant c matrices in the primal objective function
bA vector containing the right hand side of the equality constraints in the primal problem
OPTIONSA list object specifying the value of parbarrier